# `pyrolite`

<img src="https://raw.githubusercontent.com/morganjwilliams/pyrolite/develop/docs/source/_static/icon.jpg" alt="pyrolite Logo" width="30%" align="right">

<p align="left">
  <a href="https://pypi.python.org/pypi/pyrolite/">
    <img src="https://img.shields.io/pypi/v/pyrolite.svg" alt="PyPI"></a>
  <a href="https://pyrolite.readthedocs.io/">
     <img src="https://readthedocs.org/projects/pyrolite/badge/?version=develop" alt="Docs"/></a>
  <a href="https://pypi.python.org/pypi/pyrolite/">
    <img src="https://img.shields.io/pypi/pyversions/pyrolite.svg"
         alt="Compatible Versions"></a>
  <a href="https://github.com/python/black">
    <img src="https://img.shields.io/badge/code%20style-black-000000.svg"
         alt="Code Style: Black"></a>
</p>
<p align="left">
<a href="https://zenodo.org/badge/latestdoi/137172322">
  <img src="https://zenodo.org/badge/137172322.svg" alt="DOI"></a>
<a href="https://github.com/morganjwilliams/pyrolite/blob/master/LICENSE" >
  <img src="https://img.shields.io/badge/License-CSIRO_BSD/MIT_License-blue.svg"
       alt="License: CSIRO Modified BSD/MIT License"></a>
<a href="https://pypistats.org/packages/pyrolite" >
  <img src="https://img.shields.io/pypi/dm/pyrolite.svg?style=flat"
        alt="pyrolite downloads" ></a>
</p>


### Install

```bash
pip install pyrolite
```

### Build Status


| **master** | **develop** |
|:----------:|:-----------:|
| [![Build Status](https://travis-ci.org/morganjwilliams/pyrolite.svg?branch=master)](https://travis-ci.org/morganjwilliams/pyrolite) | [![Build Status](https://travis-ci.org/morganjwilliams/pyrolite.svg?branch=develop)](https://travis-ci.org/morganjwilliams/pyrolite) |
| [![Coverage Status](https://coveralls.io/repos/github/morganjwilliams/pyrolite/badge.svg?branch=master)](https://coveralls.io/github/morganjwilliams/pyrolite?branch=master) | [![Coverage Status](https://coveralls.io/repos/github/morganjwilliams/pyrolite/badge.svg?branch=develop)](https://coveralls.io/github/morganjwilliams/pyrolite?branch=develop) |

**Maintainer**: Morgan Williams (morgan.williams _at_ csiro.au)

### Contributing

The long-term aim of this project is to be designed, built and supported by (and for)
the geochemistry community. For more information, see the [documentation](https://pyrolite.readthedocs.io/), particularly the [
Contributing page](https://pyrolite.readthedocs.io/en/latest/contributing.html) and [Code of Conduct](https://pyrolite.readthedocs.io/en/latest/conduct.html).
